@@ -1,14 +1,5 @@
 # Contains tests for the CompletingMatrices.R file in the byname package.
 
-# Need to put dplyr before testthat.
-# If not, the "matches" function in dplyr overrides the "matches" function in testthat,
-# and tests containing the string "(" don't work as expected.
-
-library(dplyr)
-library(magrittr)
-library(matsbyname)
-library(testthat)
-
 ###########################################################
 context("Sorting rows and columns")
 ###########################################################
@@ -105,7 +96,7 @@ test_that("sort_rows_cols works with different-length arguments for lists", {
   DF[[2, "m"]] <- mlist
   DF[[3, "m"]] <- mlist
   res <- DF %>% 
-    mutate(
+    dplyr::mutate(
       sorted = sort_rows_cols(m)
     )
   expect_equal(res$sorted[[1]][[1]], m_sorted)
@@ -334,7 +325,7 @@ test_that("complete_rows_cols works as expected", {
   # Test what happens when matrices are missing row or column names or both.
   A <- matrix(1:4, nrow = 2)
   expect_equal(complete_rows_cols(A), A)
-  expect_equal(complete_rows_cols(A %>% set_rownames(c("r1", "r2")) %>% set_colnames(c("c1", "c2"))), 
+  expect_equal(complete_rows_cols(A %>% magrittr::set_rownames(c("r1", "r2")) %>% magrittr::set_colnames(c("c1", "c2"))), 
                matrix(c(1, 3, 0, 0, 
                         2, 4, 0, 0, 
                         0, 0, 0, 0,
@@ -345,7 +336,7 @@ test_that("complete_rows_cols works as expected", {
   
   # Test with list for x and NULL for matrix
   expect_equal(complete_rows_cols(a = list(A, A)), list(A, A))
-  B <- A %>% set_rownames(c("r1", "r2")) %>% set_colnames(c("c1", "c2")) %>% 
+  B <- A %>% magrittr::set_rownames(c("r1", "r2")) %>% magrittr::set_colnames(c("c1", "c2")) %>% 
     setrowtype("row") %>% setcoltype("col")
   B_completed <- matrix(c(1, 3, 0, 0, 
                           2, 4, 0, 0, 
